#include "ThingSpeak.h"
#include <ESP8266WiFi.h>
#include "DHTesp.h"

char ssid[] = "CISCO";                    // your network SSID (name) 
char pass[] = "0123456789ABC";    // your network password
int keyIndex = 0;                         // your network key Index number (needed only for WEP)
WiFiClient  client;

DHTesp dht;

unsigned long myChannelNumber = XXXXXXXXXXX;
const char * myWriteAPIKey = "XXXXXXXXXXXXX";

String myStatus = "";

void setup()
{
  Serial.begin(115200);  // Initialize serial
  WiFi.mode(WIFI_STA); 
  ThingSpeak.begin(client);  // Initialize ThingSpeak
  dht.setup(D4, DHTesp::DHT11); // Connect DHT sensor to D4
}


void loop() 
{
  // Connect or reconnect to WiFi
  if(WiFi.status() != WL_CONNECTED)
  {
    Serial.print("Attempting to connect to SSID: ");
    Serial.println(ssid);
    while(WiFi.status() != WL_CONNECTED)
    {
      WiFi.begin(ssid, pass);  // Connect to WPA/WPA2 network. Change this line if using open or WEP network
      Serial.print(".");
      delay(5000);     
    } 
    Serial.println("\nConnected.");
  }

  float humidity = dht.getHumidity();
  float temperature = dht.getTemperature(); 
  float rssi = WiFi.RSSI();
  float HeatIndex = dht.computeHeatIndex(temperature,humidity,0);
  float DewPoint = dht.computeDewPoint(temperature,humidity,0);
  float Perception = dht.computePerception(temperature,humidity,0);
 
  // set the fields with the values
  ThingSpeak.setField(1, temperature);
  ThingSpeak.setField(2, humidity);
  ThingSpeak.setField(3, rssi);
  ThingSpeak.setField(4, HeatIndex);
  ThingSpeak.setField(5, DewPoint);
  ThingSpeak.setField(6, Perception);
  Serial.print("Teplota: ");
  Serial.println(temperature); 
  Serial.print("Vlhkost: ");
  Serial.println(humidity); 
  Serial.print("HeatIndex: ");
  Serial.println(HeatIndex); 
  Serial.print("DewPoint: ");
  Serial.println(DewPoint); 
  Serial.print("Perception: ");
  Serial.println(Perception);   
  Serial.print("RSSI: ");
  Serial.println(rssi); 
  // figure out the status message
  myStatus="OK";
  
  // set the status
  ThingSpeak.setStatus(myStatus);
  
  // write to the ThingSpeak channel
  int x = ThingSpeak.writeFields(myChannelNumber, myWriteAPIKey);
  if(x == 200)
  {
    Serial.println("Channel update successful.");
  }
  else
  {
    Serial.println("Problem updating channel. HTTP error code " + String(x));
  }
 
  delay(5*60*1000); // Wait 5 minute to update the channel again
}
